﻿namespace BPA.MES.Base.Application.Services
{
    /// <summary>
    /// 名    称 ：成品管理服务 
    /// 创 建 人 ：yangxiao  
    /// 创建时间 ：2023/3/2 16:11:04 
    /// 描    述 ：基础数据管理 
    /// </summary>
    [ApiDescriptionSettings("基础数据管理", Order = 4, Name = "FinalsInfo", KeepName = true, SplitCamelCase = true, KeepVerb = true)]
    public class FinalsInfoService : IFinalsInfoService, ITransient, IDynamicApiController
    {
        private readonly ISqlSugarClient _dbContext;
        public FinalsInfoService(ISqlSugarClient db)
        {
            _dbContext = db;
        }
        /// <summary>
        /// 增加
        /// </summary>
        /// <param name="input"></param>
        /// <returns></returns>
        [HttpPost]
        public async Task<bool> Add(FinalsInfoAddInput input)
        {
            var r_entity = await _dbContext.Queryable<Pztj_FinalsInfoEntity>().FirstAsync(x => x.Name == input.Name);
            if (r_entity != null)
            {
                throw Oops.Bah("名称已存在!");
            }
            Pztj_FinalsInfoEntity entity = input.Adapt<Pztj_FinalsInfoEntity>();
            return await _dbContext.Insertable(entity).IgnoreColumns(ignoreNullColumn: true).ExecuteCommandIdentityIntoEntityAsync();
        }
        /// <summary>
        /// 删除
        /// </summary>
        /// <param name="input"></param>
        /// <returns></returns>
        /// <exception cref="NotImplementedException"></exception>
        [HttpPost]
        public async Task<bool> Del(FinalsInfoDelInput input)
        {
            var res = await _dbContext.Deleteable<Pztj_FinalsInfoEntity>().Where(x => x.Id == input.Id).ExecuteCommandHasChangeAsync();
            return res;
        }
        /// <summary>
        /// 详情
        /// </summary>
        /// <param name="Id"></param>
        /// <returns></returns>
        /// <exception cref="NotImplementedException"></exception>
        [HttpGet]
        public async Task<FinalsInfoOutput> Detail(string Id)
        {
            var entity = await _dbContext.Queryable<Pztj_FinalsInfoEntity>().FirstAsync(x => x.Id == Id);
            FinalsInfoOutput output = entity.Adapt<FinalsInfoOutput>();
            return output;
        }
        /// <summary>
        /// 列表
        /// </summary>
        /// <returns></returns>
        /// <exception cref="NotImplementedException"></exception>
        [HttpGet]
        public async Task<List<FinalsInfoOutput>> List()
        {
            var entity = await _dbContext.Queryable<Pztj_FinalsInfoEntity>().ToListAsync();
            List<FinalsInfoOutput> output = entity.Adapt<List<FinalsInfoOutput>>();
            return output;
        }
        /// <summary>
        /// 分页
        /// </summary>
        /// <param name="input"></param>
        /// <returns></returns>
        [HttpPost]
        public async Task<SqlSugarPagedList<FinalsInfoOutput>> PagedList(FinalsInfoQueryPageInput input)
        {
            var entity = await _dbContext.Queryable<Pztj_FinalsInfoEntity>()
                .LeftJoin<Pztj_CraftsInfoEntity>((a,b)=>a.CraftId==b.Id)
                .LeftJoin<RecipesInfoEntity>((a, b, c) => a.RecipeId == c.Id)
                .WhereIF(!string.IsNullOrEmpty(input.Name),a=>a.Name.Contains(input.Name))
                .WhereIF(!string.IsNullOrEmpty(input.Code), a => a.Name.Contains(input.Code))
                 .Select((a,b,c)=> new FinalsInfoOutput
                 {
                     Id = a.SelectAll().Id,
                     RecipeName = c.Name,
                     CraftName = b.Name
                 })
                .ToPagedListAsync(input.PageIndex, input.PageSize);
            SqlSugarPagedList<FinalsInfoOutput> output = entity.Adapt<SqlSugarPagedList<FinalsInfoOutput>>();
            return output;
        }
        /// <summary>
        /// 下拉
        /// </summary>
        /// <returns></returns>
        /// <exception cref="NotImplementedException"></exception>
        [HttpGet]
        public async Task<dynamic> SelectList()
        {
            var entity = await _dbContext.Queryable<Pztj_FinalsInfoEntity>().Select(x => new
            {
                key = x.Id,
                value = x.Name
            }).ToListAsync();
            return entity;
        }
        /// <summary>
        /// 更新
        /// </summary>
        /// <param name="input"></param>
        /// <returns></returns>
        /// <exception cref="NotImplementedException"></exception>
        [HttpPost]
        public async Task<bool> Update(FinalsInfoUpdateInput input)
        {
            Pztj_FinalsInfoEntity entity = input.Adapt<Pztj_FinalsInfoEntity>();
            var res = await _dbContext.Updateable(entity).ExecuteCommandHasChangeAsync();
            return res;
        }
    }
}

